import { message } from "ant-design-vue";
import { studentSubjectiveConfirmData } from "@/api/checkPage";
import { useMarkStore } from "@/store";

export default function useTask(ids: string[]) {
  const markStore = useMarkStore();
  const studentIds = $ref(ids);

  let currentStudentId = $ref("");
  const currentIndex = $computed(() => studentIds.indexOf(currentStudentId));
  const isFirst = $computed(() => currentIndex === 0);
  const isLast = $computed(() => currentIndex === studentIds.length - 1);
  const isMultiStudent = $computed(() => studentIds.length > 1);

  async function getNextStudent() {
    if (isLast) {
      void message.warning("已经是最后一份！");
      return;
    }
    await updateTask(studentIds[currentIndex + 1]);
  }

  async function getPreviousStudent() {
    if (isFirst) {
      void message.warning("已经是第一份！");
      return;
    }
    await updateTask(studentIds[currentIndex - 1]);
  }

  async function updateTask(studentId) {
    const res = await studentSubjectiveConfirmData(studentId);
    if (!res.data) {
      markStore.message = res.message || "数据错误";
      return;
    }
    res.data.taskId = res.data.studentId;
    const newTask = res.data;
    newTask.sheetUrls = newTask.sheetUrls || [];
    newTask.sliceUrls = [...newTask.sheetUrls];
    markStore.currentTask = newTask;
    currentStudentId = studentId;
    updateTaskGroupInfo();
  }

  let taskQuestionInfo = $ref({});
  function updateTaskGroupInfo() {
    taskQuestionInfo = {};
    if (!markStore.currentTask) return;

    markStore.currentTask.questionList.forEach((question) => {
      const qno = `${question.mainNumber * 1000}${question.subNumber}`;
      taskQuestionInfo[qno] = {
        groupNumber: question.groupNumber,
        score: question.markerScore,
      };
    });
  }

  return {
    getNextStudent,
    getPreviousStudent,
    taskQuestionInfo,
    studentIds,
    currentStudentId,
    currentIndex,
    isFirst,
    isLast,
    isMultiStudent,
  };
}
